Documentation
¶
Overview ¶
Package git enables basic git operations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BasicRepoInfo ¶
type BasicRepoInfo struct {
URL string `json:"repo_url"`
Owner string `json:"repo_owner"`
Name string `json:"repo_name"`
HeadBranch string `json:"head_branch"`
HeadCommit string `json:"head_commit"`
}
BasicRepoInfo contains basic information about a repository, all retrievable without signing git operations.
func ReadBasicRepoInfo ¶
func ReadBasicRepoInfo(l zerolog.Logger, repoPath string) (BasicRepoInfo, error)
ReadBasicRepoInfo returns basic information about the repository at the given path. This info is used to gather more detailed information from GitHub if possible.
Click to show internal directories.
Click to hide internal directories.